!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

*****************************************************************************
        subroutine det_chan_n_expid_from_output_chan(NHIGGS,NHPLUS,whichexpt,
     &		output_chan,experiment_id,exp_chan)
*****************************************************************************
        implicit none
	character*5 whichexpt
	integer NHIGGS,NHPLUS,experiment_id,exp_chan,output_chan,tev_offset

#include "tables-indexing-lep_cb.h"
#include "tables-indexing-tev_cb.h"


	if(output_chan .eq. 0) then
		experiment_id = 0
	else
	if(whichexpt .eq. 'onlyH') then
		tev_offset=0
		experiment_id=2
		exp_chan=output_chan
	elseif(whichexpt .eq. 'onlyL') then
		experiment_id=1
		exp_chan=output_chan
	elseif((whichexpt .eq. 'LandH') .or. (whichexpt .eq. 'onlyP')) then
		tev_offset=nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS+nLEP_NDCHN*NHIGGS**2
		if(output_chan .le. tev_offset) then
			experiment_id=1
			exp_chan=output_chan
		elseif(output_chan .gt. tev_offset) then
			experiment_id=2
			exp_chan=output_chan-tev_offset
		endif
	elseif(whichexpt .eq. 'singH') then
		tev_offset=nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS
		if(output_chan .le. tev_offset) then
			experiment_id=1
			exp_chan=output_chan
		elseif(output_chan .gt. tev_offset) then
			experiment_id=2
			exp_chan=output_chan-tev_offset
		endif
	endif
	endif

	end



!******************************************************************
	subroutine write_table_key(file_id,NHIGGS,NHPLUS,whichexpt)
!******************************************************************
	implicit none
	character*5 whichexpt
	logical useHAD,useLEP,useSingH
        integer NHIGGS,NHPLUS,file_id
        integer output_chan,channel,number_channels

#include "tables-indexing-lep_cb.h"
#include "tables-indexing-tev_cb.h"

	call determine_topology_flags(whichexpt,
     &          useHAD,useLEP,useSingH)

	number_channels = 0

	if(useLEP) then
	  if(useSingH) then
		number_channels = nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS
	  else
		number_channels = nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS
     &				  +nLEP_NDCHN*NHIGGS**2
	  endif
	endif

	if(useHAD) then
	  number_channels = number_channels 
     &		+ nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS+nTEV_NDCHN*NHIGGS**2
	endif

	do output_chan=0,number_channels
	  call write_output_channel(file_id,NHIGGS,NHPLUS,whichexpt,
     &                                  output_chan)
	enddo

	end



!******************************************************************
	subroutine write_output_channel(file_id,NHIGGS,NHPLUS,whichexpt,
     &					output_chan)
!******************************************************************
	implicit none
	character*5 whichexpt
	character*4 prefix
        integer NHIGGS,NHPLUS,file_id,m,n,i,j,findi,findj
        integer TEV_reaction_number,TEV_analysis_number
        integer LEP_reaction_number,LEP_analysis_number
	integer output_chan,channel,experiment_id,analysis,offset

#include "tables-indexing-lep_cb.h"
#include "tables-indexing-tev_cb.h"

	if(file_id .eq. 6) then	
		prefix='    '	
	else
		prefix=' #  '
	endif

 	call det_chan_n_expid_from_output_chan(NHIGGS,NHPLUS,whichexpt,
     &          output_chan,experiment_id,channel)

! 16.1.2009
	if(output_chan .eq. 0) then
	write(file_id,90) prefix
 90	FORMAT(A4,'  0: no analysis applies')
	endif

	if(experiment_id .eq. 1) then
	  n=LEP_reaction_number(NHIGGS,NHPLUS,channel)
	  analysis=LEP_analysis_number(NHIGGS,NHPLUS,channel)
	  
	  if(channel .le. nLEP_NSneutCHN*NHIGGS) then
	    if(id_Sneut(analysis) .eq. nLEPhZ_bbZ) then
	      write(file_id,142) prefix,output_chan,n,n
 142          FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_tautauZ)  then
	      write(file_id,143) prefix,output_chan,n,n
 143          FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_anyZ)  then
	      write(file_id,1400) prefix,output_chan,n,n
 1400         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> anything (OPAL, EPJC 27(2003)311)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_gamgamZ)  then
	      write(file_id,1401) prefix,output_chan,n,n
 1401         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> gamma gamma (LEP, LHWG note 2002-02)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_jjZ)  then
	      write(file_id,1402) prefix,output_chan,n,n
 1402         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> hadrons (LEP combined limit)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_invisZ)  then
	      write(file_id,1403) prefix,output_chan,n,n
 1403         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> invisible (hep-ex/0107032)')
            elseif(id_Sneut(analysis) .eq. nDELPHIbbh_4b)  then
	      write(file_id,1404) prefix,output_chan,n
 1404         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 4 b, H CP even, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHIbba_4b)  then
	      write(file_id,1405) prefix,output_chan,n
 1405         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 4 b, H CP odd, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHIbbh_2b2tau)  then
	      write(file_id,1406) prefix,output_chan,n
 1406         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 2b 2tau, H CP even, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHIbba_2b2tau)  then
	      write(file_id,1407) prefix,output_chan,n
 1407         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 2b 2tau, H CP odd, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHItautauh_4tau)  then
	      write(file_id,1408) prefix,output_chan,n
 1408         FORMAT (A4,I3,':  e+ e- -> tau tau H(',I1,') -> 4 tau, H CP even, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHItautaua_4tau)  then
	      write(file_id,1409) prefix,output_chan,n
 1409         FORMAT (A4,I3,':  e+ e- -> tau tau H(',I1,') -> 4 tau, H CP odd, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHIhZ_invisZ)  then
	      write(file_id,1410) prefix,output_chan,n,n
 1410         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> invisible, DELPHI (hep-ex/0401022)')
            elseif(id_Sneut(analysis) .eq. nL3hZ_invisZ)  then
	      write(file_id,1411) prefix,output_chan,n,n
 1411         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> invisible, L3 (hep-ex/0501033)')
            elseif(id_Sneut(analysis) .eq. nOPALhZ_invisZ)  then
	      write(file_id,1412) prefix,output_chan,n,n
 1412         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> invisible, OPAL (hep-ex/0707.0373)')
            elseif(id_Sneut(analysis) .eq. nOPALbbh_2b2tau)  then
	      write(file_id,1413) prefix,output_chan,n
 1413         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 2b 2tau, H CP even, OPAL (hep-ex/0111010)') 
            elseif(id_Sneut(analysis) .eq. nOPALbba_2b2tau)  then
	      write(file_id,1414) prefix,output_chan,n
 1414         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 2b 2tau, H CP odd, OPAL (hep-ex/0111010)') 
 	    endif
	  elseif((channel .gt. nLEP_NSneutCHN*NHIGGS) 
     &		 .and. (channel .le. nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS)) then
c ... charged Higgs analyses
	    offset=nLEP_NSneutCHN
            if(id_Schar(analysis-offset) .eq. nOPALhphm_2tau2nu)  then
	      write(file_id,1501) prefix,output_chan,n,n
 1501         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 2 tau 2 nu, OPAL (hep-ex/0812.0267)') 
            elseif(id_Schar(analysis-offset) .eq. nOPALhphm_2jtaunu)  then
	      write(file_id,1502) prefix,output_chan,n,n
 1502         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 2 jets tau nu, OPAL (hep-ex/0812.0267)') 
            elseif(id_Schar(analysis-offset) .eq. nOPALhphm_4j)  then
	      write(file_id,1503) prefix,output_chan,n,n
 1503         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 4 jets, OPAL (hep-ex/0812.0267)') 
            elseif(id_Schar(analysis-offset) .eq. nLEPhphm_4j)  then
	      write(file_id,1504) prefix,output_chan,n,n
 1504         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 4 jets, LEP (hep-ex/0107031)') 
            elseif(id_Schar(analysis-offset) .eq. nDELPHIhphm_4j)  then
	      write(file_id,1505) prefix,output_chan,n,n
 1505         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 4 jets, DELPHI (hep-ex/0404012)') 
            elseif(id_Schar(analysis-offset) .eq. nDELPHIhphm_2tau2nu)  then
	      write(file_id,1506) prefix,output_chan,n,n
 1506         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 2 tau 2 nu, DELPHI (hep-ex/0404012)') 
	    endif
	  else
c ... double Higgs analyses
	    offset=nLEP_NSneutCHN+nLEP_NScharCHN 
	    i=findi(NHIGGS,n)
	    j=findj(NHIGGS,n)
	      if(id_Dneut(analysis-offset) .eq. nLEPh2Z_h1h1Z_4bZ) then
		write(file_id,150) prefix,output_chan,j,j,i,i,i
 150 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2Z_h1h1Z_4tauZ) then
		write(file_id,160) prefix,output_chan,j,j,i,i,i
 160 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_4b) then
		write(file_id,180) prefix,output_chan,j,i,j,i
 180 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'),  H(',I1,'), H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_4tau) then 
		write(file_id,190) prefix,output_chan,j,i,j,i
 190 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'),  H(',I1,'), H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_h1h1h1_6b) then 
		write(file_id,200) prefix,output_chan,j,i,j,i,i,i
 200 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'), H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_h1h1h1_6tau) then
		write(file_id,210) prefix,output_chan,j,i,j,i,i,i
 210 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'), H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2Z_h1h1Z_2b2tau) then
		write(file_id,220) prefix,output_chan,j,j,i,i,i
 220 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> b b, tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_2b2tau) then
		write(file_id,230) prefix,output_chan,j,i,j,i
 230 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'), H(',I1,') -> b b, H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_2tau2b) then
		write(file_id,240) prefix,output_chan,j,i,j,i
 240 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'), H(',I1,') -> tau tau, H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
	      endif
	  endif
	endif

	if(experiment_id .eq. 2) then

	  n=TEV_reaction_number(NHIGGS,NHPLUS,channel)
	  analysis=TEV_analysis_number(NHIGGS,NHPLUS,channel)

	  if(channel .le. nTEV_NSneutCHN*NHIGGS) then

! Tevatron analyses
	   if(tev_id_Sneut(analysis) .eq. nCDF1009_3047) write(file_id,1001) prefix,output_chan,n
	   if(tev_id_Sneut(analysis) .eq. nCDF10235) write(file_id,1002) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10583) write(file_id,1003) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06166) write(file_id,1004) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06223) write(file_id,1005) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF8961_D05536) write(file_id,1009) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10105) write(file_id,1010) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06220) write(file_id,1011) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10239) write(file_id,1013) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05726) write(file_id,1014) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01011_1931) write(file_id,1015) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01106_4555) write(file_id,1017) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF0906_1014) write(file_id,1018) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05873) write(file_id,1019) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF7307v3) write(file_id,1020) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06177) write(file_id,1022) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00803_1514) write(file_id,1023) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10439) write(file_id,1024) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF9290_D05645) write(file_id,1025) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05757) write(file_id,1026) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF0809_3930) write(file_id,1027) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF9465_D05754) write(file_id,1028) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10599) write(file_id,1029) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05871) write(file_id,1030) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01012_0874) write(file_id,1031) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF0906_5613) write(file_id,1032) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01106_4885) write(file_id,1033) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05740) write(file_id,1034) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00912_5285) write(file_id,1035) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF0911_3935) write(file_id,1036) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00901_1887) write(file_id,1037) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00712_0598) write(file_id,1039) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10099_D06063) write(file_id,1040) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05985) write(file_id,1042) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF9999) write(file_id,1043) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05739) write(file_id,1044) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00806_0611) write(file_id,1045) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01001_4481) write(file_id,1048) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00903_4800) write(file_id,1049) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05845) write(file_id,1050) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06008) write(file_id,1051) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF9998_D05983) write(file_id,1052) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10485) write(file_id,1053) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10010) write(file_id,1054) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF1001_4468) write(file_id,1057) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF_D0_1001_4162) write(file_id,1058) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF_D0_1005_3216) write(file_id,1059) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06219) write(file_id,1060) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01107_1268) write(file_id,1061) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06083abslim) write(file_id,1062) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06083) write(file_id,1063) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10241_D06096) write(file_id,1064) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01008_3564) write(file_id,1065) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06219singHWW) write(file_id,1066) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10599singHWW) write(file_id,1067) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05974) write(file_id,1068) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06171) write(file_id,1069) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06179) write(file_id,1070) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06183) write(file_id,1071) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06229) write(file_id,1072) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10500) write(file_id,1073) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10573) write(file_id,1074) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10574) write(file_id,1075) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10596) write(file_id,1076) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF1106_4782) write(file_id,1077) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF_D0_1108_3331) write(file_id,1078) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF_D0_1103_3233) write(file_id,1079) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF_D0_1107_5518) write(file_id,1080) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF_D0_1107_5518bb) write(file_id,1081) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDFD0_1107_4960) write(file_id,1082) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06227) write(file_id,1083) prefix,output_chan,n,n

! LHC analyses           
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_134) write(file_id,3001) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1108_5064) write(file_id,3002) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1109_3357) write(file_id,3003) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_052) write(file_id,3004) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1109_3615) write(file_id,3005) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1202_1415) write(file_id,3006) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1202_1414) write(file_id,3007) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1108_5895) write(file_id,3008) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_133) write(file_id,3009) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1107_5003) write(file_id,3010) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_132) write(file_id,3011) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_103) write(file_id,3012) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_112) write(file_id,3013) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_135) write(file_id,3014) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1106_2748) write(file_id,3015) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1109_5945) write(file_id,3016) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_163) write(file_id,3017) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_148) write(file_id,3018) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1112_2577) write(file_id,3019) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nATLAS2011_157_CMS11_023) write(file_id,3020) prefix,output_chan,n 
           if(tev_id_Sneut(analysis) .eq. nCMS1202_1488) write(file_id,3021) prefix,output_chan,n 
           if(tev_id_Sneut(analysis) .eq. nCMS1202_1489) write(file_id,3022) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nCMS1202_1997) write(file_id,3023) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nCMS1202_3478) write(file_id,3024) prefix,output_chan,n,n           
           if(tev_id_Sneut(analysis) .eq. nCMS1202_1416low) write(file_id,3025) prefix,output_chan,n,n
           if(tev_id_Sneut(analysis) .eq. nCMS1202_1416hi) write(file_id,3026) prefix,output_chan,n,n           
           if(tev_id_Sneut(analysis) .eq. nCMS11_029SM) write(file_id,3027) prefix,output_chan,n          
           if(tev_id_Sneut(analysis) .eq. nCMS1202_1487) write(file_id,3028) prefix,output_chan,n,n           
           if(tev_id_Sneut(analysis) .eq. nCMS11_011) write(file_id,3029) prefix,output_chan,n 
           if(tev_id_Sneut(analysis) .eq. nCMS11_031) write(file_id,3030) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCMS1104_1619) write(file_id,3031) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCMS11_029) write(file_id,3032) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCMS1102_5429) write(file_id,3033) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nATLAS1202_1408) write(file_id,3034) prefix,output_chan,n
           
	  elseif((channel .gt. nTEV_NSneutCHN*NHIGGS) 
     &		 .and. (channel .le. nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS)) then
c ... charged Higgs analyses
	    offset=nTEV_NSneutCHN
          
           if(tev_id_Schar(analysis-offset) .eq. nD00908_1811cs) write(file_id,1046) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nD00908_1811taunu) write(file_id,1047) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nCDF0907_1269low) write(file_id,1055) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nCDF0907_1269hi) write(file_id,1056) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nCMS11_008) write(file_id,1084) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nATLAS2011_138) write(file_id,1085) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nATLAS2011_151) write(file_id,1086) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nATLAS2011_094) write(file_id,1087) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nCDF7712) write(file_id,1088) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nCDF8353) write(file_id,1089) prefix,output_chan,n,n

          else
c ... double neutral Higgs analyses        
	   offset=nTEV_NSneutCHN+nTEV_NScharCHN
	   i=findi(NHIGGS,n)
	   j=findj(NHIGGS,n)
	      if(tev_id_Dneut(analysis-offset) .eq. nD0_0905_3381_4mu) then
		write(file_id,2001) prefix,output_chan,j,j,i,i
 2001 		FORMAT (A4,I3,':  p p-bar -> H(',I1,'), H(',I1,') -> H(',I1,') H(',I1,') -> 4 mu (D0 hep-ex/0905.3381)')
              elseif(tev_id_Dneut(analysis-offset) .eq. nD0_0905_3381_2mu2tau) then
		write(file_id,2002) prefix,output_chan,j,j,i,i
 2002 		FORMAT (A4,I3,':  p p-bar -> H(',I1,'), H(',I1,') -> H(',I1,') H(',I1,') -> 2 mu 2 tau (D0 hep-ex/0905.3381)')
              endif
	  endif
	  
	endif

 1001	FORMAT (A4,I3,': p p-bar -> Z H(',I1,') -> l l b b-bar, CDF with 4.1 fb^-1 (hep-ex/1009.3047)')
 1002	FORMAT (A4,I3,': p p-bar -> Z H(',I1,') -> l l b b-bar, CDF with 5.7 fb^-1 (CDF note 10235)')
 1003   FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar + miss. E_T (V=W,Z), CDF with 7.8 fb^-1 SM combined (CDF note 10583)')
 1004	FORMAT (A4,I3,': p p-bar -> Z H(',I1,') -> l l b b-bar, D0 with 8.6 fb^-1 (D0 note 6166)')
 1005	FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar + miss. E_T (V=W,Z), D0 with 8.4 fb^-1 SM combined (D0 note 6223)')
 1009	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM combined with 2-4.8 fb ^-1 (hep-ex/0712.2383)')
 1010	FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> 3 b jets, CDF with 2.5 fb^-1 (CDF note 10105)')
 1011   FORMAT (A4,I3,': p p-bar -> W H(',I1,'), H -> b b-bar, D0 with 8.5 fb^-1 (D0 note 6220)')
 1013   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> l nu b b-bar, CDF with 5.7 fb^-1 (CDF note 10239)')
 1014   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> 3 b jets, D0 with 2.6 fb^-1 (D0 note 5726)')
 1015   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> 3 b jets, D0 with 5.2 fb^-1 (hep-ex/1011.1931)')
 1017   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> tau tau, D0 with 5.4 fb^-1 absolute limits (D0 hep-ex/1106.4555)')
 1018   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> tau tau, CDF with 1.8 fb^-1 absolute limits (CDF hep-ex/0906.1014)')
 1019   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> 3 Ws, D0 with 3.6 fb^-1 (D0 note 5873)') 
 1020   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> 3 Ws, CDF with 2.7 fb^-1 (CDF note 7307 version 3)')
 1022   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, D0 with 8.2 fb^-1 (D0 note 6177)')
 1023   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, D0 with 1.1 fb^-1 absolute limits (D0 hep-ex/0803.1514)')
 1024	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> tau tau, CDF with 6.0 fb^-1 SM combined (CDF note 10439)')
 1025   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM combined with 1-2.4 fb^-1 (hep-ex/0804.3423)')
 1026	FORMAT (A4,I3,': p p-bar -> H(',I1,') -> W W -> l l, D0 with 3.0 fb^-1 (D0 note 5757)')
 1027   FORMAT (A4,I3,': p p-bar -> single H(',I1,') -> W W, CDF with 3.0 fb^-1 (hep-ex/0809.3930)')
 1028	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM combined with 3 fb^-1 (hep-ex/0808.0534)')
 1029   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, CDF with 8.2 fb^-1 SM combined (CDF note 10599)')
 1030   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, D0 with 4.2 fb^-1 SM combined (D0 note 5871)')
 1031   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> l nu b b-bar, D0 with 5.3k fb^-1 (hep-ex/1012.0874)')
 1032   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> l nu b b-bar, CDF with 2.7 fb^-1 (hep-ex/0906.5613)')
 1033   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 7.3 fb^-1 (hep-ex/1106.4885)')
 1034	FORMAT (A4,I3,': p p-bar -> H(',I1,') -> tau tau, D0 with 2.2 fb^-1 absolute limits (D0 note 5740)')
 1035	FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar + miss. E_T (V=W,Z), D0 with 5.2 fb^-1 (hep-ex/0912.5285)')
 1036	FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar + miss. E_T (V=W,Z), CDF with 2.1 fb^-1 (hep-ex/0911.3935)')
 1037   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, D0 with 2.7 fb^-1 (D0 hep-ex/0901.1887)')
 1039	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, SM combined with 0.44 fb^-1 (D0 hep-ex/0712.0598)')
 1040	FORMAT (A4,I3,': p p-bar -> H(',I1,') -> tau tau, CDF & D0 combined with up to 2.2 fb^-1 absolute limits (hep-ex/1003.3363)')
 1042   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 2.7 fb^-1 (D0 note 5985)')
 1043   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, SM combined with 2.0-4.8 fb^-1 (CDF note 9999)')
 1044   FORMAT (A4,I3,': p p-bar -> ttH(',I1,') -> ttbb, D0 with 2.1 fb^-1 (D0 note 5739)')
 1045   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> Z gamma, D0 with 1.0 fb^-1 absolute limits (D0 hep-ex/0806.0611)')
 1046   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> cs, D0 with 1.0 fb^-1 BR(t->H+b) limits (D0 hep-ex/0908.1811)')
 1047   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> tau nu, D0 with 1.0 fb^-1 BR(t->H+b) limits (D0 hep-ex/0908.1811)')
 1048   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, D0 with 5.4 fb^-1 (D0 hep-ex/1001.4481)')
 1049	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> tau tau, D0 with 1.0 fb^-1 SM combined (hep-ex/0903.4800)')
 1050	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> tau tau, D0 with 4.9 fb^-1 SM combined (D0 note 5845)')
 1051   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, SM combined, D0 with 2.1-5.4 fb^-1 (D0 note 6008)')
 1052   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM SM combined with 2.1-5.4 fb^-1 (hep-ex/0911.3930)')
 1053   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, CDF with 7.0 fb^-1 SM combined (CDF note 10485)')
 1054   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> b b + X, CDF with 4 fb^-1 SM combined (CDF note 10010)')
 1055   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> cs, CDF with 2.2 fb^-1 BR(t->H+b) limits, low mass part (CDF hep-ex/0907.1269)')
 1056   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> cs, CDF with 2.2 fb^-1 BR(t->H+b) limits, high mass part (CDF hep-ex/0907.1269)')
 1057   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, CDF with 4.8 fb^-1 SM combined (hep-ex/1001.4468)')
 1058   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, CDF & D0 with 4.8-5.4 fb^-1 SM combined (hep-ex/1001.4162)')
 1059   FORMAT (A4,I3,': p p-bar -> single H(',I1,') -> W W, CDF & D0 with 4.8/5.4 fb^-1 (hep-ex/1005.3216)')
 1060   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> WW/ZZ + X, D0 with 8.1 fb^-1 SM combined (D0 note 6219)')
 1061   FORMAT (A4,I3,': p p-bar -> VH(',I1,') -> VVV -> same sign di-lepton(e,mu) (V=W,Z), D0 with 5.4 fb^-1 SM combined (D0 hep-ex/1107.1268)')
 1062   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 4.3 fb^-1 absolute limits (D0 note 6083)')
 1063   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 4.3 fb^-1 (D0 note 6083)')
 1064   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM SM combined with up to 5.9/6.7 fb^-1 (hep-ex/1007.4587)')
 1065	FORMAT (A4,I3,': p p-bar -> Z H(',I1,') -> l l b b-bar, D0 with 4.2 fb^-1 (D0 hep-ex/1008.3564)')
 1066   FORMAT (A4,I3,': p p-bar -> single H(',I1,') -> W W, D0 with 8.1 fb^-1 (D0 note 6219)')
 1067   FORMAT (A4,I3,': p p-bar -> single H(',I1,') -> W W, CDF with 8.2 fb^-1 (CDF note 10599)')
 1068   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 3.7 fb^-1 absolute limits (D0 note 5974)')
 1069   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, SM combined, D0 with 5.4 fb^-1 (D0 note 6171)')
 1070   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> WW + X, D0 with 7.3 fb^-1 SM combined (D0 note 6179)')
 1071   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> WW/gam gam/tau tau/ZZ + X, D0 with 8.2 fb^-1 SM combined (D0 note 6183)')
 1072   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, SM combined, D0 with 4.3-8.6 fb^-1 (D0 note 6229)')
 1073   FORMAT (A4,I3,': p p-bar -> VH(',I1,') + X, WH -> lnutautau & ZH -> lltautau, D0 with 6.2 fb^-1 SM combined (CDF note 10500)')
 1074   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> 4l, CDF with 8.2 fb^-1 SM combined (CDF note 10573)')
 1075   FORMAT (A4,I3,': p p-bar -> ttH(',I1,') -> ttbb, CDF with 7.5 fb^-1 (CDF note 10574)')
 1076   FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar l + miss. E_T (V=W,Z), CDF with 7.5 fb^-1 SM combined (CDF note 10596)')
 1077   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> 3 b jets, CDF with 2.6 fb^-1 (hep-ex/1106.4782)')
 1078   FORMAT (A4,I3,': p p-bar -> single H(',I1,') -> W W, CDF & D0 with 8.2/8.1 fb^-1 SM combined (hep-ex/1108.3331)')
 1079   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM combined with up to 7.1/8.2 fb^-1 (hep-ex/1103.3233)')
 1080   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM combined with up to 8.2/8.6 fb^-1 (hep-ex/1107.5518)')
 1081   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 H-> bb SM combined with up to 8.2/8.6 fb^-1 (hep-ex/1107.5518)')
 1082   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, CDF & D0 with 7.0 & 8.2 fb^-1 (hep-ex/1107.4960)')
 1083   FORMAT (A4,I3,': p p-bar -> b H(',I1,'), H(',I1,') -> bb/tau tau, D0 with 7.3 fb^-1 (D0 note 6227)')
 1084   FORMAT (A4,I3,': p p -> t t, t -> H+(',I1,') b, H+(',I1,') -> tau nu, CMS with 1.0 fb^-1 BR(t->H+b) limits (CMS-PAS-HIG-11-008)')
 1085   FORMAT (A4,I3,': p p -> t t, t -> H+(',I1,') b, H+(',I1,') -> tau nu, ATLAS with 1.03 fb^-1 BR(t->H+b)*BR(H+ -> tau nu) limits (ATLAS-CONF-2011-138)')
 1086   FORMAT (A4,I3,': p p -> t t, t -> H+(',I1,') b, H+(',I1,') -> tau nu, ATLAS with 1.03 fb^-1 BR(t->H+b) limits (ATLAS-CONF-2011-151)')
 1087   FORMAT (A4,I3,': p p -> t t, t -> H+(',I1,') b, H+(',I1,') -> cs, ATLAS with 0.035 fb^-1 BR(t->H+b) limits (ATLAS-CONF-2011-094)')
 1088   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> tau nu, D0 with 0.192 fb^-1 BR(t->H+b) limits (CDF note 7712)')
 1089   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> tau nu, D0 with 0.335 fb^-1 BR(t->H+b) limits (CDF note 8353)')


 3001   FORMAT (A4,I3,': p p -> single H(',I1,') -> W W, ATLAS with 1.7 fb^-1 (ATLAS-CONF-2011-134)')
 3002   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> Z Z -> llqq, ATLAS SM combined with 1.04 fb^-1 (hep-ex/1108.5064)')
 3003   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> V V -> lnulnu (V=W,Z), ATLAS SM combined with 1.04 fb^-1 (hep-ex/1109.3357)')
 3004   FORMAT (A4,I3,': p p -> single H(',I1,') -> W W, ATLAS with 0.035 fb^-1 (ATLAS-CONF-2011-052)')
 3005   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> W W -> lnujj, ATLAS SM combined with 1.04 fb^-1 (hep-ex/1109.3615)')
 3006   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> Z Z -> 4l, ATLAS SM combined with 4.8 fb^-1 (hep-ex/1202.1415)')
 3007   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> gamma gamma, ATLAS SM combined with 4.9 fb^-1 (hep-ex/1202.1414)')
 3008   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> gamma gamma, ATLAS SM combined with 1.08 fb^-1 (hep-ex/1108.5895)')
 3009   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> tau tau, ATLAS SM combined with 1.06 fb^-1 (ATLAS-CONF-2011-133)')
 3010   FORMAT (A4,I3,': p p -> H(',I1,') -> tau tau, ATLAS with 0.036 fb^-1 absolute limits (hep-ex/1107.5003)')
 3011   FORMAT (A4,I3,': p p -> H(',I1,') -> tau tau, ATLAS with 1.06 fb^-1 absolute limits (ATLAS-CONF-2011-132)')
 3012   FORMAT (A4,I3,': p p -> VH(',I1,') -> b b-bar + miss. E_T (V=W,Z), ATLAS with 1.04 fb^-1 (ATLAS-CONF-2011-103)')
 3013   FORMAT (A4,I3,': p p -> H(',I1,') + X, SM combined, ATLAS with 1.04-1.21 fb^-1 (ATLAS-CONF-2011-112)')
 3014   FORMAT (A4,I3,': p p -> H(',I1,') + X, SM combined, ATLAS with 1.0-2.3 fb^-1 (ATLAS-CONF-2011-135)')
 3015   FORMAT (A4,I3,': p p -> H(',I1,') + X, SM combined, ATLAS with up to 0.04 fb^-1 (hep-ex/1106.2748)')
 3016   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> Z Z -> 4l, ATLAS SM combined with 2.1 fb^-1 (hep-ex/1109.5945)')
 3017   FORMAT (A4,I3,': p p -> H(',I1,') + X, SM combined, ATLAS with up to 4.9 fb^-1 (ATLAS-CONF-2011-163)')
 3018   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> V V -> lnulnu (V=W,Z), ATLAS SM combined with 2.05 fb^-1 (ATLAS-CONF-2011-148)')
 3019   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> V V -> lnulnu (V=W,Z), ATLAS SM combined with 2.05 fb^-1 (hep-ex/1112.2577)')
 3020   FORMAT (A4,I3,': p p -> H(',I1,') + X, SM combined, ATLAS & CMS with up to 2.3 fb^-1 (ATLAS-CONF-2011-157 & CMS PAS HIG-11-023)')
 3021   FORMAT (A4,I3,': p p -> H(',I1,') + X, SM combined, CMS with up to 4.8 fb^-1 (hep-ex/1202.1488)')
 3022   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> V V -> lnulnu (V=W,Z), CMS SM combined with 4.6 fb^-1 (hep-ex/1202.1489)')
 3023   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> Z Z -> 4l, CMS SM combined with 4.7 fb^-1 (hep-ex/1202.1997)')
 3024   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> V V -> lnulnu (V=W,Z), CMS SM combined with 4.6 fb^-1 (hep-ex/1202.3478)')
 3025   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> Z Z -> llqq, CMS SM combined with 4.6 fb^-1, low mass (hep-ex/1202.1416)')
 3026   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> Z Z -> llqq, CMS SM combined with 4.6 fb^-1, high mass (hep-ex/1202.1416)')
 3027   FORMAT (A4,I3,': p p -> H(',I1,') -> tau tau, CMS with 4.6 fb^-1 absolute limits (CMS-PAS-HIG-11-029)')
 3028   FORMAT (A4,I3,': p p -> H(',I1,') + X, H(',I1,') -> gamma gamma, CMS SM combined with 4.8 fb^-1 (hep-ex/1202.1487)')
 3029   FORMAT (A4,I3,': p p -> H(',I1,') + X, SM combined, CMS with up to 1.1 fb^-1 (CMS PAS HIG-11-011)')
 3030   FORMAT (A4,I3,': p p -> VH(',I1,') -> b b-bar + miss. E_T (V=W,Z), CMS with 4.7 fb^-1 (CMS-PAS-HIG-11-031)')
 3031   FORMAT (A4,I3,': p p -> H(',I1,') -> tau tau, CMS with 0.036 fb^-1 absolute limits (hep-ex/1104.1619)')
 3032   FORMAT (A4,I3,': p p -> H(',I1,') -> tau tau, CMS with 4.6 fb^-1 absolute limits (CMS-PAS-HIG-11-029)')
 3033   FORMAT (A4,I3,': p p -> single H(',I1,') -> W W, CMS with 0.041 fb^-1 (hep-ex/1102.5429)')
 3034   FORMAT (A4,I3,': p p -> H(',I1,') + X, SM combined, ATLAS with up to 4.9 fb^-1 (hep-ex/1202.1408)')

	end
