!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

!******************************************************
        real*8 function lhc7_rHZ_uub(x)
!******************************************************
!* Used LO calculation and NNLO QCD and EW K-factors.
!* This reproduces the numbers of arXiv:1101.0593 [hep-ph] 
!* to better than 1%. (PDF: MSTW 2008 NNLO)
!******************************************************
!* x : Higgs mass in GeV
!* fit: strictly valid in range [90:300], deviations from data below 0.5%
!*      slight extrapolation to range [80:310] is allowed.
!* 27/4/2011, Oliver Brein (revised: 29/4/2011)
!******************************
        implicit none
        real*8 a,b,c,d,x

        a = 0.486454541874656
        b = -9.78294961659717e-05
        c = 3.63077314490425e-07
        d = 1.62568809034006e-09

        lhc7_rHZ_uub=0d0
                                                                        
        if(x .lt. 80d0) then
        write(*,*)'function lhc7_rHZ_uub might not be a good fit (m_H < 80 GeV)'
        endif
        if((x .ge. 80d0) .and. (x .le. 310d0)) then
        lhc7_rHZ_uub=a+b*x+c*x**2+d*x**3
        endif
        if(x .gt. 310d0) then
        write(*,*)'function lhc7_rHZ_uub might not be a good fit (m_H > 310 GeV)'
        endif
                                                                                                                                        
        end
        