!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

!******************************************************
        real*8 function lhc7_cs_Htt_SM(x)
!******************************************************
!* fit to Htt associate production for a 7 TeV pp collider (NLO QCD)
!* from: https://twiki.cern.ch/twiki/bin/view/LHCPhysics/CERNYellowReportPageAt7TeV
!* (see also: arXiv:1101.0593 [hep-ph])
!******************************************************
!* lhc7_cs_Htt_SM : CS in pikobarn
!* x : Higgs mass in GeV
!* fit: strictly valid in range [90:300], deviations from data table below 0.09%
!*      slight extrapolation to range [80:310] is allowed.
!* 28/4/2011, Oliver Brein (revised: 29/4/2011)
!******************************
        implicit none
        real*8 x,a,b,c,d,e,f,g,h,i,j,k,log_lhc7_cs_Htt

        i = -39971676.9941267
        j = 2653157.13644392
        k = -77796.6733121375
        a = 1327.78664579512
        b = -14.5877618295949
        c = 0.107288400289656
        d = -0.000537490086401566
        e = 1.80902905455147e-06
        f = -3.9136405951968e-09
        g = 4.91531525150969e-12
        h = -2.7227634594385e-15


        if(x. lt. 80d0) then
        write(*,*) 'function lhc7_cs_Htt(Mh) called out of range (m_H < 80 GeV). Value set to -1.' 
	lhc7_cs_Htt_SM=-1d0
	return
	endif
	if((x .ge. 80d0) .and. (x .le. 310d0)) then
        log_lhc7_cs_Htt=i/x**3+j/x**2+k/x+a+b*x+c*x**2+d*x**3+e*x**4+f*x**5+g*x**6+h*x**7        
        endif
        if(x .gt. 310d0) then  
        write(*,*) 'function lhc7_cs_Htt(Mh) called out of range (m_H > 310 GeV). Value set to -1.' 
	lhc7_cs_Htt_SM=-1d0
	return
        endif
        
        lhc7_cs_Htt_SM=exp(log_lhc7_cs_Htt)
                                                                                                                                        
        end
        