!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

!******************************************************
        real*8 function lhc7_cs_bbH_SM(x)
!******************************************************
!* fit to single Higgs production via b b-bar annihilation 
!* for a 7 TeV pp collider (NNLO QCD).
!* Numbers generated with bbh@nnlo v. 1.3 (PDF: MSTW 2008 NNLO) 
!* with input parameters according to arXiv:1101.0593 [hep-ph].
!******************************************************
!* lhc7_cs_bbH_SM : CS in pikobarn
!* x : Higgs mass in GeV
!* fit: valid in range [70:1020], deviations from data table below 0.03%
!* 28/4/2011, Oliver Brein (revised: 29/4/2011)
!******************************
        implicit none
        real*8 x,a1,b1,c1,d1,e1,f1,g1,h1,i1,j1,k1,log_lhc7_cs_bbH
  
        i1 = 118393.552970347d0
        j1 = -8500.14886364116d0
        k1 = 263.791637006274d0
        a1 = -0.686328023297912d0
        b1 = -0.0263560546043822d0
        c1 = 4.25891594291875d-05
        d1 = -6.72674484878268d-08
        e1 = 7.68476123865973d-11
        f1 = -5.76921139630906d-14
        g1 = 2.52072437882796d-17
        h1 = -4.83311237805624d-21


        if(x. lt. 70d0) then
        write(*,*) 'function lhc7_cs_bbH_SM(Mh) called out of range (m_H < 70 GeV). Value set to -1.' 
	lhc7_cs_bbH_SM=-1d0
	return
	endif
        if((x .ge. 70d0) .and. (x .le. 1020d0)) then
        log_lhc7_cs_bbH=i1/x**3+j1/x**2+k1/x+a1+b1*x+c1*x**2+d1*x**3+e1*x**4+f1*x**5+g1*x**6+h1*x**7        
        endif
        if(x .gt. 1020d0) then  
        write(*,*) 'function lhc7_cs_bbH_SM(Mh) called out of range (m_H > 1020 GeV). Value set to -1.' 
	lhc7_cs_bbH_SM=-1d0
	return
        endif
                
        lhc7_cs_bbH_SM=exp(log_lhc7_cs_bbH)
                                                                                                                                        
        end
        