!*************************************************************************
! This file is part of
!
!       HiggsBounds 3.7.0 beta (fortran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: Comput.Phys.Commun.182:2605-2631,2011 (arXiv:1102.1898 [hep-ph])
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! started 21/10/2011
!*************************************************************************

!******************************************************
        real*8 function lhc7_cs_ggH_SM(x)
!******************************************************
!* fit to single Higgs production via gluon fusion
!* for a 7 TeV pp collider (NNLO QCD).
!* from: https://twiki.cern.ch/twiki/bin/view/LHCPhysics/CERNYellowReportPageAt7TeV
!* The central value is taken as the central value of the "envelope" of dFG
!* and ABPS calculations. (see also arXiv:1101.0593 [hep-ph]).
!******************************************************
!* lhc7_cs_ggH_SM : CS in pikobarn
!* x : Higgs mass in GeV
!* fit: strictly valid in range [90:1000], deviations from data table below 0.7%
!*      slight extrapolation to range [70:1020] is allowed.
!* 28/4/2011, Oliver Brein
!******************************
        implicit none
        real*8 x,a1,b1,c1,d1,e1,f1,g1,h1,i1,j1,k1,log_lhc7_cs_ggH
        real*8 a2,b2,c2,d2,e2,f2,g2,h2,i2,j2,k2
        real*8 a4,b4,c4,d4,e4,f4,g4,h4,i4,j4,k4

        i1 = -85603015.521997d0
        j1 = 6941984.31251259d0
        k1 = -244947.750609768d0
        a1 = 4950.82618727165d0
        b1 = -63.2176954377208d0
        c1 = 0.533660334934763d0
        d1 = -0.00301613182704942d0
        e1 = 1.12759303766809d-05
        f1 = -2.67221592382065d-08
        g1 = 3.63147829951788d-11
        h1 = -2.15347176335811d-14

        i2 = 51070883304284.0d0
        j2 = -1552089421964.15d0
        k2 = 21112948901.0225d0
        a2 = -169263570.522153d0
        b2 = 885574.031624522d0
        c2 = -3159.07396220896d0
        d2 = 7.78068120007463d0
        e2 = -0.0130635643285566d0
        f2 = 1.43079922813315d-05
        g2 = -9.23037324948215d-09
        h2 = 2.66321685448228d-12

        i4 = 10900459554.9426d0
        j4 = -201678340.6349d0
        k4 = 1580812.67532986d0
        a4 = -7020.59324259514d0
        b4 = 19.7497547635457d0
        c4 = -0.0369012863838364d0
        d4 = 4.64363462326695d-05
        e4 = -3.89242044844257d-08
        f4 = 2.08122780674357d-11
        g4 = -6.40921146546335d-15
        h4 = 8.62467069372484d-19

        if(x. lt. 70d0) then
        write(*,*) 'function lhc7_cs_ggH_SM(Mh) called out of range (m_H < 70 GeV). Value set to -1.' 
	lhc7_cs_ggH_SM=-1d0
	return
	endif
        if((x .ge. 70d0) .and. (x .le. 300d0)) then
        log_lhc7_cs_ggH=i1/x**3+j1/x**2+k1/x+a1+b1*x+c1*x**2+d1*x**3+e1*x**4+f1*x**5+g1*x**6+h1*x**7
        endif
        if((x .gt. 300d0) .and. (x .le. 380d0)) then  
        log_lhc7_cs_ggH=i2/x**3+j2/x**2+k2/x+a2+b2*x+c2*x**2+d2*x**3+e2*x**4+f2*x**5+g2*x**6+h2*x**7
        endif
        if((x .gt. 380d0) .and. (x .le. 1020d0)) then
        log_lhc7_cs_ggH=i4/x**3+j4/x**2+k4/x+a4+b4*x+c4*x**2+d4*x**3+e4*x**4+f4*x**5+g4*x**6+h4*x**7
        endif
        if(x .gt. 1020d0) then  
        write(*,*) 'function lhc7_cs_ggH_SM(Mh) called out of range (m_H > 1020 GeV). Value set to -1.' 
	lhc7_cs_ggH_SM=-1d0
	return
        endif

        lhc7_cs_ggH_SM=exp(log_lhc7_cs_ggH)
                                                                                                                                        
        end
        